Tessellations
=============

Tessellation
------------

.. autoclass:: sokoenginepy.game.Tessellation
    :members:
    :undoc-members:


SokobanTessellation
-------------------

.. autoclass:: sokoenginepy.game.SokobanTessellation
    :show-inheritance:
    :special-members: __init__


HexobanTessellation
-------------------

.. autoclass:: sokoenginepy.game.HexobanTessellation
    :show-inheritance:
    :special-members: __init__


TriobanTessellation
-------------------

.. autoclass:: sokoenginepy.game.TriobanTessellation
    :show-inheritance:
    :special-members: __init__


OctobanTessellation
-------------------

.. autoclass:: sokoenginepy.game.OctobanTessellation
    :show-inheritance:
    :special-members: __init__


BaseTessellation
----------------

.. autoclass:: sokoenginepy.game.BaseTessellation
    :members:
    :undoc-members:
